@@ -147,8 +147,8 @@ def apply_log(log, petri_net, initial_marking, final_marking, parameters=None, v
     if parameters is None:
         parameters = dict()
 
-    if not check_soundness.check_relaxed_soundness_net_in_fin_marking(petri_net, initial_marking, final_marking):
-        raise Exception("trying to apply alignments on a Petri net that is not a relaxed sound net!!")
+    if not check_soundness.check_easy_soundness_net_in_fin_marking(petri_net, initial_marking, final_marking):
+        raise Exception("trying to apply alignments on a Petri net that is not a easy sound net!!")
 
     start_time = time.time()
     activity_key = parameters[
@@ -241,7 +241,7 @@ def apply_log_multiprocessing(log, petri_net, initial_marking, final_marking, pa
     if parameters is None:
         parameters = dict()
 
-    if not check_soundness.check_relaxed_soundness_net_in_fin_marking(petri_net, initial_marking, final_marking):
+    if not check_soundness.check_easy_soundness_net_in_fin_marking(petri_net, initial_marking, final_marking):
         raise Exception("trying to apply alignments on a Petri net that is not a relaxed sound net!!")
 
     activity_key = parameters[
