@@ -1,7 +1,16 @@
 from pm4py.algo.enhancement.roles.common import algorithm
 from pm4py.util import xes_constants as xes
-from pm4py.util import constants
 from collections import Counter
+from pm4py.util import exec_utils
+
+from enum import Enum
+from pm4py.util import constants
+
+
+class Parameters(Enum):
+    ROLES_THRESHOLD_PARAMETER = "roles_threshold_parameter"
+    RESOURCE_KEY = constants.PARAMETER_CONSTANT_RESOURCE_KEY
+    ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
 
 
 def apply(df, parameters=None):
@@ -24,10 +33,8 @@ def apply(df, parameters=None):
     if parameters is None:
         parameters = {}
 
-    resource_key = parameters[
-        constants.PARAMETER_CONSTANT_RESOURCE_KEY] if constants.PARAMETER_CONSTANT_RESOURCE_KEY in parameters else xes.DEFAULT_RESOURCE_KEY
-    activity_key = parameters[
-        constants.PARAMETER_CONSTANT_ACTIVITY_KEY] if constants.PARAMETER_CONSTANT_ACTIVITY_KEY in parameters else xes.DEFAULT_NAME_KEY
+    resource_key = exec_utils.get_param_value(Parameters.RESOURCE_KEY, parameters, xes.DEFAULT_RESOURCE_KEY)
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes.DEFAULT_NAME_KEY)
     activity_resource_couples = Counter(dict(df.groupby([resource_key, activity_key]).size()))
 
     return algorithm.apply(activity_resource_couples, parameters=parameters)
