@@ -54,9 +54,9 @@ def apply(log, petri_net, initial_marking, final_marking, parameters=None, varia
     # execute the following part of code when the variant is not specified by the user
     if variant is None:
         if not (
-                petri.check_soundness.check_relaxed_soundness_net_in_fin_marking(petri_net, initial_marking,
-                                                                                 final_marking)):
-            # in the case the net is not a relaxed sound workflow net, we must apply token-based replay
+                petri.check_soundness.check_easy_soundness_net_in_fin_marking(petri_net, initial_marking,
+                                                                              final_marking)):
+            # in the case the net is not a easy sound workflow net, we must apply token-based replay
             variant = TOKEN_BASED
         else:
             # otherwise, use the align-etconformance approach (safer, in the case the model contains duplicates)
