@@ -1,4 +1,5 @@
 from collections.abc import Mapping, Sequence
+import copy
 
 
 class Event(Mapping):
@@ -23,6 +24,14 @@ class Event(Mapping):
     def __repr__(self):
         return str(dict(self))
 
+    def __hash__(self):
+        return hash(frozenset(dict(self)))
+
+    def __copy__(self):
+        event = Event()
+        event._dict = copy.copy(self._dict)
+        return event
+
 
 class EventStream(Sequence):
 
@@ -34,6 +43,9 @@ class EventStream(Sequence):
         self._classifiers = kwargs['classifiers'] if 'classifiers' in kwargs else {}
         self._list = list(*args)
 
+    def __hash__(self):
+        return hash(tuple(self))
+
     def __getitem__(self, key):
         return self._list[key]
 
@@ -76,6 +88,15 @@ class EventStream(Sequence):
     def _get_classifiers(self):
         return self._classifiers
 
+    def __copy__(self):
+        event_stream = EventStream()
+        event_stream._attributes = copy.copy(self._attributes)
+        event_stream._extensions = copy.copy(self._extensions)
+        event_stream._omni = copy.copy(self._omni)
+        event_stream._classifiers = copy.copy(self._classifiers)
+        event_stream._list = copy.copy(self._list)
+        return event_stream
+
     attributes = property(_get_attributes)
     extensions = property(_get_extensions)
     omni_present = property(_get_omni)
@@ -88,6 +109,9 @@ class Trace(Sequence):
         self._set_attributes(kwargs['attributes'] if 'attributes' in kwargs else {})
         self._list = list(*args)
 
+    def __hash__(self):
+        return hash(tuple(self))
+
     def __getitem__(self, key):
         return self._list[key]
 
@@ -140,6 +164,12 @@ class Trace(Sequence):
     def __str__(self):
         return str(self.__repr__())
 
+    def __copy__(self):
+        trace = Trace()
+        trace._attributes = copy.copy(self._attributes)
+        trace._list = copy.copy(self._list)
+        return trace
+
 
 class EventLog(EventStream):
     def __init__(self, *args, **kwargs):
@@ -156,3 +186,12 @@ class EventLog(EventStream):
 
     def __str__(self):
         return str(self.__repr__())
+
+    def __copy__(self):
+        log = EventLog()
+        log._attributes = copy.copy(self._attributes)
+        log._extensions = copy.copy(self._extensions)
+        log._omni = copy.copy(self._omni)
+        log._classifiers = copy.copy(self._classifiers)
+        log._list = copy.copy(self._list)
+        return log
